/**
 * \file Per_Process_Process.hh
 * \author Scott F. H. Kaplan -- sfkaplan@cs.amherst.edu
 * \date September 2004
 * \brief A Process subclass designed for Per_Process_Consumers.
 **/



// ===================================================================
// Avoid multiple inclusion.
#if !defined (_PER_PROCESS_PROCESS_HH)
#define _PER_PROCESS_PROCESS_HH
// ===================================================================



// ===================================================================
// INCLUDES

#include "Per_Process_Writer.hh"
#include "Process.hh"
// ===================================================================



// ===================================================================
// CLASS DEFINITION

/**
 * \brief A Process subclass designed for Per_Process_Consumers.
 *
 * An extention to the Process class such that it also stores a
 * pointer to a Per_Process_Writer, used by the Per_Process_Consumer
 * to handle the reference stream of each task.
 **/
class Per_Process_Process : public Process {

public:

  /**
   * \brief The constructor.
   *
   * Initialize the process by calling the parent constructor and then
   * setting the writer (which is per-process specific) to null.
   **/
  Per_Process_Process ();

  /**
   * \brief The deconstructor.
   *
   * Flush and close the writer.
   **/
  virtual ~Per_Process_Process ();

public: // DATA MEMBERS

  /** 
   * \brief A pointer to the output stream writer for this
   *        process.
   **/
  Per_Process_Writer* writer;

}; // class Per_Process_Process
// ===================================================================



// ===================================================================
#endif // _PER_PROCESS_PROCESS_HH
// ===================================================================
